{ lib, pkgs, config,  myconfig, ... }:
let
  connexionswing  = pkgs.callPackage ./builder.nix {
    inherit (pkgs.webapps) connexionswing;
    config = myconfig.env.websites.connexionswing.integration;
    apacheUser = config.services.httpd.Inte.user;
    apacheGroup = config.services.httpd.Inte.group;
  };

  cfg = config.myServices.websites.connexionswing.integration;
in {
  options.myServices.websites.connexionswing.integration.enable = lib.mkEnableOption "enable Connexionswing's website in integration";

  config = lib.mkIf cfg.enable {
    secrets.keys = connexionswing.keys;
    services.myPhpfpm.preStart.connexionswing_dev = connexionswing.phpFpm.preStart;
    services.myPhpfpm.serviceDependencies.connexionswing_dev = connexionswing.phpFpm.serviceDeps;
    services.myPhpfpm.poolConfigs.connexionswing_dev = connexionswing.phpFpm.pool;
    services.myPhpfpm.poolPhpConfigs.connexionswing_dev = connexionswing.phpFpm.phpConfig;
    system.activationScripts.connexionswing_dev = connexionswing.activationScript;
    system.extraSystemBuilderCmds = ''
      mkdir -p $out/webapps
      ln -s ${connexionswing.app.webRoot} $out/webapps/${connexionswing.apache.webappName}
      '';
    services.websites.integration.modules = connexionswing.apache.modules;
    services.websites.integration.vhostConfs.connexionswing = {
      certName    = "eldiron";
      addToCerts  = true;
      hosts       = ["connexionswing.immae.eu" "sandetludo.immae.eu" ];
      root        = connexionswing.apache.root;
      extraConfig = [ connexionswing.apache.vhostConf ];
    };
  };
}

