{ lib, pkgs, config, myconfig,  ... }:
let
  piedsjaloux = pkgs.callPackage ./builder.nix {
    inherit (pkgs.webapps) piedsjaloux;
    config = myconfig.env.websites.piedsjaloux.production;
    apacheUser = config.services.httpd.Prod.user;
    apacheGroup = config.services.httpd.Prod.group;
  };

  cfg = config.myServices.websites.piedsjaloux.production;
in {
  options.myServices.websites.piedsjaloux.production.enable = lib.mkEnableOption "enable PiedsJaloux's website in production";

  config = lib.mkIf cfg.enable {
    secrets.keys = piedsjaloux.keys;
    services.webstats.sites = [ { name = "piedsjaloux.fr"; } ];

    services.myPhpfpm.preStart.piedsjaloux_prod = piedsjaloux.phpFpm.preStart;
    services.myPhpfpm.serviceDependencies.piedsjaloux_prod = piedsjaloux.phpFpm.serviceDeps;
    services.myPhpfpm.poolConfigs.piedsjaloux_prod = piedsjaloux.phpFpm.pool;
    system.activationScripts.piedsjaloux_prod = piedsjaloux.activationScript;
    system.extraSystemBuilderCmds = ''
      mkdir -p $out/webapps
      ln -s ${piedsjaloux.app.webRoot} $out/webapps/${piedsjaloux.apache.webappName}
      '';
    services.websites.production.modules = piedsjaloux.apache.modules;
    services.websites.production.vhostConfs.piedsjaloux = {
      certName     = "piedsjaloux";
      certMainHost = "piedsjaloux.fr";
      hosts        = [ "piedsjaloux.fr" "www.piedsjaloux.fr" ];
      root         = piedsjaloux.apache.root;
      extraConfig  = [ piedsjaloux.apache.vhostConf ];
    };
  };
}

